from click import command, argument, option, echo, style
from requests import post
from pyperclip import copy


@command()
@argument('text')
@option('--language', '-l',
        default='en-en', help='The language in which the text is written.')
@option('--no-copy',
        '-nc', default=False,
        help='The parameter that allows you to disable automatic copying to the clipboard.', is_flag=True)
@option('--api-key', '-k',
        default='b54abd1309f04aefa589c384d8a7ea5c',
        help='Bing Spell Checking API Key.')
def command_line(text: str, language: str, api_key: str, no_copy: bool):
    response = post('https://api.cognitive.microsoft.com/bing/v7.0/SpellCheck',
                    headers={'Content-Type': 'application/x-www-form-urlencoded',
                             'Ocp-Apim-Subscription-Key': api_key},
                    params={'mkt': language,
                            'mode': 'spell'},
                    data={'text': text}
                    ).json()

    start_text = text
    tokens = list()  # Create tokens list
    for token in response['flaggedTokens']:  # For each token in the list
        tokens.append(token['suggestions'][0]['suggestion'])  # Add token to tokens list
        text = text.replace(token['token'], token['suggestions'][0]['suggestion'])  # Replace spell error in the text
    if start_text == text:
        if language == 'en-en':
            echo('Your text is correct! ✨')
        elif language == 'ru-ru':
            echo('Ваш текст не содержит ошибок. ✨')
        return

    if not no_copy: copy(text)  # Copy correct writing to clipboard

    # For each token and replace it with underline in text
    for token in tokens: text = text.replace(token, style(token, underline=True))

    # Language dependent message choosing
    if language == 'en-en':
        text = f'Correct writing: {text}'
        if not no_copy: text += '\nText is in your clipboard. 🥳'
    elif language == 'ru-ru':
        text = f'Правильное написание: {text}'
        if not no_copy: text += '\nТекст уже в вашем буфере обмена. 🥳'
    echo(text)  # Printing final message
